@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::RxCmp;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::RxCmp::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 # Compare different Regexes engines plugins (Perl 5.10+)
 
@@ -260,7 +263,15 @@ sub main
 
 1;
 
-__END__
+
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::RxCmp
 
 =head1 NAME
 
@@ -273,5 +284,20 @@ compare different Regexes engines with pathological regular
 expressions. Inspired by and examples taken from
 L<http://swtch.com/~rsc/regexp/regexp1.html>.
 
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
+
