@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::SpamAssassin;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::SpamAssassin::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 use strict;
 use warnings;
@@ -13,9 +16,8 @@ our $VERSION = "0.002";
 
 use File::Temp qw(tempfile tempdir);
 use File::Copy::Recursive qw(dircopy);
-use File::ShareDir qw(module_dir);
+use File::ShareDir qw(dist_dir);
 use Time::HiRes qw(gettimeofday);
-use Benchmark::Perl::Formance::Cargo;
 
 our $count;
 our $easy_ham;
@@ -29,7 +31,7 @@ sub main {
         $easy_ham = $options->{fastmode} ? "easy_ham_subset" : "easy_ham";
 
         my $dstdir = tempdir( CLEANUP => 1 );
-        my $srcdir = module_dir('Benchmark::Perl::Formance::Cargo')."/SpamAssassin";
+        my $srcdir = dist_dir('Benchmark-Perl-Formance-Cargo')."/SpamAssassin";
 
         print STDERR "# Prepare cargo spam'n'ham files in $dstdir ...\n" if $options->{verbose} >= 3;
 
@@ -39,16 +41,19 @@ sub main {
         my $salearncfg   = "$dstdir/sa-learn.cfg";
         my $salearnprefs = "$dstdir/sa-learn.prefs";
 
-        print STDERR "# Use sa-learn: $salearn\n"      if $options->{verbose};
-        print STDERR "#          cfg: $salearncfg\n"   if $options->{verbose};
-        print STDERR "#        prefs: $salearnprefs\n" if $options->{verbose};
+        print STDERR "# Use sa-learn: $salearn\n"      if $options->{verbose} >= 3;
+        print STDERR "#          cfg: $salearncfg\n"   if $options->{verbose} >= 3;
+        print STDERR "#        prefs: $salearnprefs\n" if $options->{verbose} >= 3;
 
-        return {
-                salearn => {
-                            failed       => "did not find executable sa-learn",
-                            salearn_path => $salearn,
-                           }
-               } unless $salearn && -x $salearn;
+        if (not $salearn && -x $salearn) {
+                print STDERR "# did not find executable $salearn\n" if $options->{verbose} >= 2;
+                return {
+                        salearn => {
+                                    failed       => "did not find executable sa-learn",
+                                    salearn_path => $salearn,
+                                   }
+                       };
+        }
 
         # spam variant:
         # my $cmd    = "time /usr/bin/env perl -T $salearn --spam -L --config-file=$salearncfg --prefs-file=$salearnprefs --siteconfigpath=$dstdir --dbpath=$dstdir/db --no-sync  '$dstdir/spam_2/*'";
@@ -56,8 +61,9 @@ sub main {
         chmod 0666, $salearncfg;
         if (open SALEARNCFG, ">", $salearncfg) {
                 print SALEARNCFG "loadplugin Mail::SpamAssassin::Plugin::Bayes\n";
+                close SALEARNCFG;
         } else {
-                print STDERR "# could not write sa-learn.cfg: $salearncfg";
+                print STDERR "# could not write sa-learn.cfg: $salearncfg" if $options->{verbose} >= 2;
         }
         my $cmd = "$^X -T $salearn --ham -L --config-file=$salearncfg --prefs-file=$salearnprefs --siteconfigpath=$dstdir --dbpath=$dstdir/db --no-sync  '$dstdir/$easy_ham/*'";
         print STDERR "# $cmd\n" if $options->{verbose} >= 3;
@@ -78,8 +84,17 @@ sub main {
 
 1;
 
+
+
+
 =pod
 
+=encoding utf-8
+
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::SpamAssassin
+
 =head1 NAME
 
 Benchmark::Perl::Formance::Plugin::SpamAssassin - SpamAssassin Benchmarks
@@ -94,8 +109,20 @@ provided taken from spamassassin.org.
 It uses the executable "sa-learn" that it by default searches in
 the same path of your used perl executable ($^X).
 
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
 __END__
 
 time perl -T `which sa-learn` --ham -L --config-file=sa-learn.cfg --prefs-file sa-learn.prefs --dbpath db --no-sync  'easy_ham/*'
